@@ -37,6 +37,7 @@ class Tasks(SyncAPIResource):
         return_last_frame: Optional[bool] = None,
         service_tier: Optional[str] = None,
         execution_expires_after: Optional[int] = None,
+        generate_audio: Optional[bool] = None,
         extra_headers: Headers | None = None,
         extra_query: Query | None = None,
         extra_body: Body | None = None,
@@ -51,6 +52,7 @@ class Tasks(SyncAPIResource):
                 "return_last_frame": return_last_frame,
                 "service_tier": service_tier,
                 "execution_expires_after": execution_expires_after,
+                "generate_audio": generate_audio,
             },
             options=make_request_options(
                 extra_headers=extra_headers,
@@ -165,6 +167,7 @@ class AsyncTasks(AsyncAPIResource):
         return_last_frame: Optional[bool] = None,
         service_tier: Optional[str] = None,
         execution_expires_after: Optional[int] = None,
+        generate_audio: Optional[bool] = None,
         extra_headers: Headers | None = None,
         extra_query: Query | None = None,
         extra_body: Body | None = None,
@@ -179,6 +182,7 @@ class AsyncTasks(AsyncAPIResource):
                 "return_last_frame": return_last_frame,
                 "service_tier": service_tier,
                 "execution_expires_after": execution_expires_after,
+                "generate_audio": generate_audio,
             },
             options=make_request_options(
                 extra_headers=extra_headers,
